@@ -1,16 +1,20 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #import "OFException.h"
@@ -21,8 +25,7 @@
 OF_ASSUME_NONNULL_BEGIN
 
 /**
- * @class OFDNSQueryFailedException \
- *	  OFDNSQueryFailedException.h ObjFW/OFDNSQueryFailedException.h
+ * @class OFDNSQueryFailedException OFDNSQueryFailedException.h ObjFW/ObjFW.h
  *
  * @brief An exception indicating that a DNS query failed.
  */
@@ -71,8 +74,8 @@ OF_ASSUME_NONNULL_BEGIN
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern OFString *OFDNSResolverErrorCodeDescription(
-    OFDNSResolverErrorCode errorCode);
+extern OFString *_OFDNSResolverErrorCodeDescription(
+    OFDNSResolverErrorCode errorCode) OF_VISIBILITY_HIDDEN;
 #ifdef __cplusplus
 }
 #endif
